Documentation
¶
Index ¶
- type TCCFenceStore
- type TccFenceStoreDatabaseMapper
- func (t *TccFenceStoreDatabaseMapper) DeleteTCCFenceDO(tx *sql.Tx, xid string, branchId int64) error
- func (t *TccFenceStoreDatabaseMapper) DeleteTCCFenceDOByMdfDate(tx *sql.Tx, datetime time.Time) error
- func (t *TccFenceStoreDatabaseMapper) InitLogTableName()
- func (t *TccFenceStoreDatabaseMapper) InsertTCCFenceDO(tx *sql.Tx, tccFenceDo *model.TCCFenceDO) error
- func (t *TccFenceStoreDatabaseMapper) QueryTCCFenceDO(tx *sql.Tx, xid string, branchId int64) (*model.TCCFenceDO, error)
- func (t *TccFenceStoreDatabaseMapper) SetLogTableName(logTable string)
- func (t *TccFenceStoreDatabaseMapper) UpdateTCCFenceDO(tx *sql.Tx, xid string, branchId int64, oldStatus enum.FenceStatus, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TCCFenceStore ¶
type TCCFenceStore interface {
// QueryTCCFenceDO tcc fence do.
// param tx the tx will bind with user business method
// param xid the global transaction id
// param branchId the branch transaction id
// return the tcc fence do and error msg
QueryTCCFenceDO(tx *sql.Tx, xid string, branchId int64) (*model.TCCFenceDO, error)
// InsertTCCFenceDO tcc fence do boolean.
// param tx the tx will bind with user business method
// param tccFenceDO the tcc fence do
// return the error msg
InsertTCCFenceDO(tx *sql.Tx, tccFenceDo *model.TCCFenceDO) error
// UpdateTCCFenceDO tcc fence do boolean.
// param tx the tx will bind with user business method
// param xid the global transaction id
// param branchId the branch transaction id
// param newStatus the new status
// return the error msg
UpdateTCCFenceDO(tx *sql.Tx, xid string, branchId int64, oldStatus enum.FenceStatus, newStatus enum.FenceStatus) error
// DeleteTCCFenceDO tcc fence do boolean.
// param tx the tx will bind with user business method
// param xid the global transaction id
// param branchId the branch transaction id
// return the error msg
DeleteTCCFenceDO(tx *sql.Tx, xid string, branchId int64) error
// DeleteTCCFenceDOByMdfDate tcc fence by datetime.
// param tx the tx will bind with user business method
// param datetime modify time
// return the error msg
DeleteTCCFenceDOByMdfDate(tx *sql.Tx, datetime time.Time) error
// SetLogTableName LogTable ColumnName
// param logTableName logTableName
SetLogTableName(logTable string)
}
The TCC Fence Store
type TccFenceStoreDatabaseMapper ¶
type TccFenceStoreDatabaseMapper struct {
// contains filtered or unexported fields
}
func GetTccFenceStoreDatabaseMapper ¶
func GetTccFenceStoreDatabaseMapper() *TccFenceStoreDatabaseMapper
func (*TccFenceStoreDatabaseMapper) DeleteTCCFenceDO ¶
func (*TccFenceStoreDatabaseMapper) DeleteTCCFenceDOByMdfDate ¶
func (*TccFenceStoreDatabaseMapper) InitLogTableName ¶
func (t *TccFenceStoreDatabaseMapper) InitLogTableName()
func (*TccFenceStoreDatabaseMapper) InsertTCCFenceDO ¶
func (t *TccFenceStoreDatabaseMapper) InsertTCCFenceDO(tx *sql.Tx, tccFenceDo *model.TCCFenceDO) error
func (*TccFenceStoreDatabaseMapper) QueryTCCFenceDO ¶
func (t *TccFenceStoreDatabaseMapper) QueryTCCFenceDO(tx *sql.Tx, xid string, branchId int64) (*model.TCCFenceDO, error)
func (*TccFenceStoreDatabaseMapper) SetLogTableName ¶
func (t *TccFenceStoreDatabaseMapper) SetLogTableName(logTable string)
func (*TccFenceStoreDatabaseMapper) UpdateTCCFenceDO ¶
func (t *TccFenceStoreDatabaseMapper) UpdateTCCFenceDO(tx *sql.Tx, xid string, branchId int64, oldStatus enum.FenceStatus, newStatus enum.FenceStatus) error
Click to show internal directories.
Click to hide internal directories.